#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shakespeare
version:              2.1.7.1
visibility:           public
id:                   shakespeare-2.1.7.1-1COXynUMrU9JuSWUq55esW
key:                  shakespeare-2.1.7.1-1COXynUMrU9JuSWUq55esW
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/shakespearean-templates
synopsis:             A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.

    Shakespeare templates can be used inline with a quasi-quoter or in an external file.

    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.

    Packages that use this: xml-hamlet

    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.

category:             Web, Yesod
abi:                  f5f5fec05e84e79feb281ef84308f6c8
exposed:              True
exposed-modules:
    Text.Cassius Text.Cassius.Ordered Text.Coffee Text.Hamlet
    Text.Hamlet.RT Text.Hamlet.Runtime Text.Internal.Cassius
    Text.Internal.Css Text.Internal.CssCommon Text.Internal.Lucius
    Text.Julius Text.Lucius Text.Lucius.Ordered Text.Roy
    Text.Shakespeare Text.Shakespeare.Base Text.Shakespeare.I18N
    Text.Shakespeare.Text Text.TypeScript

hidden-modules:       Text.Hamlet.Parse Text.MkSizeType Text.IndentToBrace
import-dirs:          /usr/lib/ghc-9.6.6/site-local/shakespeare-2.1.7.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/shakespeare-2.1.7.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/shakespeare-2.1.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shakespeare
hs-libraries:         HSshakespeare-2.1.7.1-1COXynUMrU9JuSWUq55esW
depends:
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie base-4.18.2.1
    blaze-html-0.9.2.0-KqwG3G8bIEdCBkJGh5vAX5
    blaze-markup-0.8.3.0-2zM85WYFmjX1BPy9tSFYFy bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5 exceptions-0.10.7
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz ghc-prim-0.10.0
    parsec-3.1.16.1 process-1.6.19.0
    scientific-0.3.8.1-9lNiUg0NFGt8fB4Ap5FVsD template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.6-259dLbfPJk9HrfYIeZHdvQ time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-HfKtyefgs0b2egKrxLGXU0
    vector-0.13.2.0-7eILYIgfGZSAohY3MIpZY

haddock-interfaces:   /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html:         /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

